#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#  This script test the basic catalog retry strategy
#
#  Authors: Paolo Badino <paolo.badino@cern.ch>
#  Version info: $Id: test_basic_catalog_retry.py,v 1.2 2006/08/14 08:38:54 badino Exp $
#  Release: $Name:  $
#

import time
import glite.fts
import glite.data.agents.utils
import basic_catalog_retry
import unittest

# Define TestCase
class BasicCatalogRetryTestCase(unittest.TestCase):
    def testCatalogRetryVersion(self):
        # Check RetryVersion
        assert basic_catalog_retry.CatalogRetryVersion() == "1.0", "Invalid CatalogRetryVersion"
    def testCatalogRetry_1(self):    
        # Test Case 1: Do Retry File
        job  = glite.fts.Job("Job1",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","","UserDN","","",int(time.time()) - (basic_catalog_retry.RETRY_DELAY_TIME * 4));
        file = glite.fts.File("1","Job1",glite.fts.FileState.WaitingCatalogResolution,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Remote,"An error",1,0,1,0)
        file.finishTime = int(time.time()) - (basic_catalog_retry.RETRY_DELAY_TIME * 2)
        files = [file]
        r = basic_catalog_retry.CatalogRetry(job,files)
        expected = glite.fts.CatalogRetryResult.Retry
        assert r == expected, \
            ("Catalog Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testCatalogRetry_2(self):    
        # Test Case 2: Fail
        job  = glite.fts.Job("Job1",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","UserDN","","","",int(time.time()) - (basic_catalog_retry.RETRY_DELAY_TIME/2));
        file = glite.fts.File("1","Job1",glite.fts.FileState.WaitingCatalogResolution,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Agent,"An error",1,0,1,0)
        file.finisTime = int(time.time()) - (basic_catalog_retry.RETRY_DELAY_TIME * 2)
        files = [file]
        r = basic_catalog_retry.CatalogRetry(job,files)
        expected = glite.fts.CatalogRetryResult.Fail
        assert r == expected, \
            ("Catalog Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))
    def testCatalogRetry_3(self):    
        # Test Case 2: Wait
        job  = glite.fts.Job("Job1",glite.fts.JobState.Active,"MyVO","MyChannel",3,False,"","UserDN","","","",int(time.time()) - (basic_catalog_retry.RETRY_DELAY_TIME/2));
        file = glite.fts.File("1","Job1",glite.fts.FileState.WaitingCatalogResolution,"","srm://host.cern.ch/castor/cern.ch/src.txt","srm://host.cern.ch/castor/cern.ch/dest.txt",glite.fts.ErrorCategory.Remote,"An error",1,0,1,0)
        file.finisTime = int(time.time()) - (basic_catalog_retry.RETRY_DELAY_TIME/4)
        files = [file]
        r = basic_catalog_retry.CatalogRetry(job,files)
        expected = glite.fts.CatalogRetryResult.Wait
        assert r == expected, \
            ("Catalog Retry Strategy returned %s. Expected value is %s" % (str(r),str(expected)))

# Define Suite
def suite():
    suite = unittest.makeSuite(BasicCatalogRetryTestCase,'test')
    return suite

# main
if __name__=="__main__":
    # The script is started from the command line: do the test
    runner = unittest.TextTestRunner()
    runner.run(suite())
