#!/bin/bash
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#-------------------------------------------------------------------------------
# Unit tests for org.glite.data.transfer-agents actions; SRM and gridftp split
# Authors: Paolo Tedesco <paolo.tedesco@cern.ch>
# Version info: $Id: unit-test.sh,v 1.2 2008/11/17 10:17:39 ptedesco Exp $
# Release: $Name:  $
#-------------------------------------------------------------------------------
# The tests use the stub transfer service.

# install service discovery stub
function test_actions_split_sd_stub_install(){
    # create services.xml file
    cat > "${MODULE_TEST_DIR}/etc/services.xml" << EOD
<services>
  <service name="CERN-SRM">
    <parameters>
      <endpoint>httpg://host.cern.ch:8443/srm/managerv2</endpoint>
      <type>SRM</type>
      <version>2.2.0</version>
      <site>CERN</site>
      <param name="dteam:SEMountPoint">/dteam</param>
      <param name="ops:SEMountPoint">/ops</param>
    </parameters>
  </service>
  <service name="RAL-SRM">
    <parameters>
      <endpoint>httpg://host.ral.ac.uk:8443/srm/managerv2</endpoint>
      <type>SRM</type>
      <version>2.2.0</version>
      <site>RAL</site>
      <param name="dteam:SEMountPoint">/dteam</param>
      <param name="ops:SEMountPoint">/ops</param>
    </parameters>
  </service> 
  <service name="INFN-SRM">
    <parameters>
      <endpoint>httpg://host.infn.it:8443/srm/managerv2</endpoint>
      <type>SRM</type>
      <version>2.2.0</version>
      <site>INFN</site>
      <param name="dteam:SEMountPoint">/dteam</param>
      <param name="ops:SEMountPoint">/ops</param>
    </parameters>
  </service> 
</services>
EOD
}

# Install Python Catalog stub
TEST_ACTIONS_PYTHON_PACKAGES_DIR=""
function test_actions_split_python_stub_install(){
    TEST_ACTIONS_PYTHON_PACKAGES_DIR=`python -c "from distutils import sysconfig; print sysconfig.get_python_lib(1,0,prefix='${GLITE_LOCATION}')"`
    info "TEST_ACTIONS_PYTHON_PACKAGES_DIR = ${TEST_ACTIONS_PYTHON_PACKAGES_DIR}"
    cp ${MODULE_DIR}/test/catalog/python/scripts/TestCatalog.py ${MODULE_TEST_DIR}/bin
}

# Install Actions UnitTest Data (populates the database)
test_actions_split_install__DEPENDS="init_unit_test test_actions_split_sd_stub_install test_actions_split_python_stub_install"
function test_actions_split_install(){
    local SRC_DIR="${MODULE_DIR}/test/actions/srm_gridftp_split/scripts"
    local DEST_DIR="${MODULE_TEST_DIR}/bin"
   
    # populate DB
    clear_db || return ${?}
    
    # copy sql scripts and bash script to run them
    cp -v ${SRC_DIR}/testactions-split-*.sql ${DEST_DIR}
   
    (cd ${DEST_DIR} && RunSqlCmd \
        "testactions-split-insert.sql") || return ${?}
     
    # create configuration xml file
    local TEMPLATES_DIR="${GLITE_LOCATION}/share/test/"
    local AGENTS_COMMON_CONFIG_TEMPLATES="${GLITE_LOCATION}/share/config/glite-data-agents-common/config-templates"
    create_config_xml "glite-transfer-agent-test-actions-split" "${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-split.config.xml" \
        "${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-cred-myproxy.config-template.xml" \
        "${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-sd.config-template.xml" \
        "${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-python.config-template.xml" \
        "${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-dao-oracle.config-template.xml" \
        "${MODULE_DIR}/test/ts/etc/transfer-agent-ts-stub.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-catalog-python.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-dao-oracle.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-vo-actions.config-template.xml" \
        "${MODULE_CONFIG_TEMPLATES}/transfer-agent-channel-actions.config-template.xml"

    # Create the unit test configuration
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-split.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-split.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-actions-split.log-properties \
        -O agents-cred-myproxy.Server=${MYPROXY_SERVER} \
        -O agents-cred-myproxy.ProxyLifetime=300 \
        -O agents-cred-myproxy.MinValidityTime=0 \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O agents-python.PythonPath=${TEST_ACTIONS_PYTHON_PACKAGES_DIR}:${MODULE_TEST_DIR}/bin \
        -O transfer-agent-catalog-python.CatalogModule=TestCatalog \
        -O transfer-agent-vo-actions.EnableDelegation=false \
        -O transfer-agent-vo-actions.MaxFailures=6 \
        -O transfer-agent-vo-actions.ResubmitDelay=300 \
        -O transfer-agent-vo-actions.EnableUnknownSource=false \
        -O transfer-agent-vo-actions.EnableUnknownDest=true \
        -O transfer-agent-channel-actions.EnableDelegation=false \
        -O transfer-agent-ts-stub.MaxTransfers=${ts_stub_maxtransfers} \
        -O transfer-agent-ts-stub.MaxRequestSize=${ts_stub_maxrequestsize} \
        -O transfer-agent-ts-stub.StopAfterPreparation=true \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-actions-split.log \
        -O log.Priority=DEBUG
}

# Actions unit test
test_actions_split__DEPENDS="test_actions_split_install"
function test_actions_split(){
    local TEST_EXE="${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_actions_split"
    local WORK_DIR="${MODULE_TEST_DIR}/bin"
    (cd ${WORK_DIR} && env \
        GLITE_LOCATION="${MODULE_TEST_DIR}" ${TEST_EXE} -l ${MODULE_TEST_DIR} \
        -c glite-transfer-agent-test-actions-split)
    return ${?}
}     

