#!/bin/bash
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

export TESTS_CGSI_TRACE=1
export CONFIG_SERVICE_FLAGS="-v"

# Install SD stub Target
function test_agents_sd_stub_install(){

    cat > ${MODULE_TEST_DIR}/etc/services.xml << EOD
<services>
  <service name="Stub_Catalog">
    <parameters>
      <endpoint>none</endpoint>
      <type>TestPythonCatalog</type>
      <version>0.0.0</version>
    </parameters>
  </service>
  <service name="Stub_Catalog_CERN">
    <parameters>
      <endpoint>test://localhost:1234</endpoint>
      <type>TestLocalPythonCatalog</type>
      <version>0.0.0</version>
      <site>CERN</site>
    </parameters>
  </service>
  <service name="CERN-SRM">
    <parameters>
      <endpoint>httpg://srm.cern.ch:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>CERN</site>
      <param name="AGENTS_VO_1:SEMountPoint">/castor/cern.ch/dteam/</param>
    </parameters>
  </service>
  <service name="INFN-SRM">
    <parameters>
      <endpoint>httpg://srm.infn.it:8443/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>INFN</site>
      <param name="AGENTS_VO_1:SEMountPoint">/castor/infn.it/dteam/</param>
    </parameters>
  </service>
  <service name="LOCAL-SRM-V1">
    <parameters>
      <endpoint>httpg://localhost:8043/srm/managerv1</endpoint>
      <type>SRM</type>
      <version>1.1.0</version>
      <site>LOCAL</site>
      <param name="AGENTS_VO_1:SEMountPoint">/stub/home/dteam/</param>
    </parameters>
  </service>
  <service name="LOCAL-SRM-V2">
    <parameters>
      <endpoint>httpg://localhost:8044/srm/managerv2</endpoint>
      <type>SRM</type>
      <version>2.2.0</version>
      <site>LOCAL</site>
      <param name="AGENTS_VO_1:SEMountPoint">/stub/home/dteam/</param>
    </parameters>
  </service>
  <service name="LOCAL-SRMCOPY-V2">
    <parameters>
      <endpoint>httpg://127.0.0.1:8045/srm/managerv2</endpoint>
      <type>SRM</type>
      <version>2.2.0</version>
      <site>LOCAL-SRM</site>
      <param name="AGENTS_VO_1:SEMountPoint">/stub/home/dteam/</param>
    </parameters>
  </service>
</services>
EOD
}

TEST_AGENTS_PYTHON_PACKAGES_DIR=""
# Install Python Catalog stub -->
function test_agents_python_stub_install(){
    # python path
    TEST_AGENTS_PYTHON_PACKAGES_DIR=`python -c "from distutils import sysconfig; print sysconfig.get_python_lib(1,0,prefix='${GLITE_LOCATION}')"`
    # Copy Python test
    cp ${MODULE_DIR}/test/catalog/python/scripts/TestCatalog.py ${MODULE_TEST_DIR}/bin 
}
        
# Install Actions UnitTest Data
test_agents_ora_install__DEPENDS="init_unit_test test_agents_sd_stub_install test_agents_python_stub_install"
function test_agents_ora_install(){

    # clear db
    clear_db 
    # Populate DB
    local DEST_DIR="${MODULE_TEST_DIR}/bin"
    local SOURCE_DIR="${MODULE_DIR}/test/agents/scripts"
    cp ${SOURCE_DIR}/testagents-*.sql ${DEST_DIR}
    
    (cd ${DEST_DIR} && RunSqlCmd \
        "testagents-t_channel_insert.sql" \
        "testagents-t_channel_vo_share_insert.sql") || return ${?}
    
    local FILL_T_JOB="${DEST_DIR}/testagents-t_job_insert.sql"
    local USER_DELEG_ID=123456 
    info "${SQLPLUS_CMD} @ ${FILL_T_JOB} \"${MY_USER_DN}\" \"${MYPROXY_USER_PASSPHRASE}\" \"${USER_DELEG_ID}\"" 
    (cd ${DEST_DIR} && 
        ${SQLPLUS_CMD} @ ${FILL_T_JOB} "${MY_USER_DN}" "${MYPROXY_USER_PASSPHRASE}" "${USER_DELEG_ID}") || return ${?}

    (cd ${DEST_DIR} && RunSqlCmd \
        "testagents-t_file_insert.sql") || return ${?}
    
    # Copy My Certificate as if it was delegated
    (cd ${MODULE_TEST_DIR}/bin && ${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_setup_test_cred_ora \
        -u "${MY_USER_DN}" -i 123456 -p ${MYPROXY_CERT} -U ${ORA_USER} -P ${ORA_PWD} -C ${ORA_CONNECTSTRING}) || return ${?}

    # Create Template for the UnitTest
    create_config_xml "glite-transfer-agent-test-agents-ora" \
        ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-oracle.config.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-sd.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-dao-oracle.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-dao-oracle.config-template.xml

    # Create Template for the UnitTest (VO-Agent)
    create_config_xml "glite-transfer-agent-test-agents-vo-ora" \
        ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-vo-oracle.config.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-cred-myproxy.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-sd.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-python.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-dao-oracle.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-cred-deleg.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-catalog-python.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-dao-oracle.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-vo-actions.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-vo-actions-python.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-vo-agent.config-template.xml

    # Create Template for the UnitTest (Channel-Agent)
    create_config_xml "glite-transfer-agent-test-agents-channel-ora" \
        ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel-oracle.config.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-cred-myproxy.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-sd.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-dao-oracle.config-template.xml \
        ${MODULE_DIR}/test/ts/etc/transfer-agent-ts-stub.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-cred-deleg.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-dao-oracle.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-channel-actions.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-channel-agent.config-template.xml

    # Create Template for the UnitTest (Channel-Agent - UrlCopy)
    create_config_xml "glite-transfer-agent-test-agents-channel-urlcopy-ora" \
        ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel-urlcopy-oracle.config.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-cred-myproxy.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-sd.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-dao-oracle.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-cred-deleg.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-dao-oracle.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-ts-urlcopy-urlcopy.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-channel-actions.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-channel-agent.config-template.xml

    # Create Template for the UnitTest (Channel-Agent - SrmCopy)
    create_config_xml "glite-transfer-agent-test-agents-channel-srmcopy-ora" \
        ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel-srmcopy-oracle.config.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-cred-myproxy.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-sd.config-template.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-dao-oracle.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-cred-deleg.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-dao-oracle.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-ts-urlcopy-srmcopy.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-channel-actions.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-channel-agent.config-template.xml
        
    # Create UnitTest configuration
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-oracle.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-ora.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-ora.log-properties \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-agents-oracle.log \
        -O log.Priority=DEBUG

    # VO Agent
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-vo-oracle.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-vo-ora.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-vo-ora.log-properties \
        -O agents-cred-myproxy.Server=${MYPROXY_SERVER} \
        -O agents-cred-myproxy.ProxyLifetime=300 \
        -O agents-cred-myproxy.MinValidityTime=10 \
        -O transfer-agent-cred-deleg.MinValidityTime=10 \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O agents-python.PythonPath=${TEST_AGENTS_PYTHON_PACKAGES_DIR}:${MODULE_TEST_DIR}/bin:${PYTHON_LIB_PATH}/glite/fts/strategies \
        -O transfer-agent-catalog-python.CatalogModule=TestCatalog \
        -O transfer-agent-vo-actions.EnableDelegation=true \
        -O transfer-agent-vo-actions.MaxFailures=3 \
        -O transfer-agent-vo-actions.ResubmitDelay=10 \
        -O transfer-agent-vo-actions.EnableUnknownSource=false \
        -O transfer-agent-vo-actions.EnableUnknownDest=false \
        -O transfer-agent-vo-actions-python.RetryModule=smarter_retry \
        -O transfer-agent-vo-actions-python.RetryParams="MaxFailures=3;HoldEnabled=0;DefaultRetryDelay=5" \
        -O transfer-agent-vo-actions-python.CatalogRetryModule=basic_catalog_retry \
        -O transfer-vo-agent.Name=AGENTS_VO_1 \
        -O transfer-vo-agent.Retry_Type=glite:PythonRetry \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-agents-vo-oracle.log \
        -O log.Priority=DEBUG
    # Channel Agent 1
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel-oracle.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel1-ora.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel1-ora.log-properties \
        -O agents-cred-myproxy.Server=${MYPROXY_SERVER} \
        -O agents-cred-myproxy.ProxyLifetime=300 \
        -O agents-cred-myproxy.MinValidityTime=10 \
        -O transfer-agent-cred-deleg.MinValidityTime=10 \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O transfer-agent-ts-stub.MaxRequestSize=1 \
        -O transfer-agent-channel-actions.EnableDelegation=true \
        -O transfer-channel-agent.Name=AGENTS_channel_1 \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-agents-channel1-oracle.log \
        -O log.Priority=DEBUG
    # Channel Agent 2 
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel-oracle.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel2-ora.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel2-ora.log-properties \
        -O agents-cred-myproxy.Server=${MYPROXY_SERVER} \
        -O agents-cred-myproxy.ProxyLifetime=300 \
        -O agents-cred-myproxy.MinValidityTime=10 \
        -O transfer-agent-cred-deleg.MinValidityTime=10 \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O transfer-agent-ts-stub.MaxRequestSize=10 \
        -O transfer-agent-channel-actions.EnableDelegation=true \
        -O transfer-channel-agent.Name=AGENTS_channel_2 \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-agents-channel2-oracle.log \
        -O log.Priority=DEBUG
    # Channel Agent 3 (UrlCopy)
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel-urlcopy-oracle.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel3-ora.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel3-ora.log-properties \
        -O agents-cred-myproxy.Server=${MYPROXY_SERVER} \
        -O agents-cred-myproxy.ProxyLifetime=300 \
        -O agents-cred-myproxy.MinValidityTime=10 \
        -O transfer-agent-cred-deleg.MinValidityTime=10 \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O transfer-agent-ts-urlcopy.MaxTransfers=10 \
        -O transfer-agent-channel-actions.EnableDelegation=true \
        -O transfer-channel-agent.Name=AGENTS_channel_3 \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-agents-channel-urlcopy-oracle.log \
        -O log.Priority=DEBUG
    # Channel Agent 4 (SrmCopy)
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel-srmcopy-oracle.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel4-ora.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-agents-channel4-ora.log-properties \
        -O agents-cred-myproxy.Server=${MYPROXY_SERVER} \
        -O agents-cred-myproxy.ProxyLifetime=300 \
        -O agents-cred-myproxy.MinValidityTime=10 \
        -O transfer-agent-cred-deleg.MinValidityTime=10 \
        -O agents-dao-oracle.User=${ORA_USER} \
        -O agents-dao-oracle.Password=${ORA_PWD} \
        -O agents-dao-oracle.ConnectString=${ORA_CONNECTSTRING} \
        -O transfer-agent-channel-actions.EnableDelegation=true \
        -O transfer-channel-agent.Name=AGENTS_channel_4 \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-agents-channel-srmcopy-oracle.log \
        -O log.Priority=DEBUG
}


# Create configuration for SRM 1.1 Server Stub 
test_agents_srm_stub_server_1_1_install__DEPENDS="init_unit_test"
function test_agents_srm_stub_server_1_1_install(){
    # Create Template for the SRM 1.1 Stub
    create_config_xml "glite-srm-util-stub-server-1_1" ${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-1.1.config.xml \
        ${SRM_UTIL_CPP_TEST_DIR}/config/srm-util-stub-server-1.1.config-template.xml
    # Create configuration for SRM 1.1 Stub 
    config_generator -f ${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-1.1.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-1.1.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-1.1.log-properties \
        -O srm-util-stub-server-1_1.Port=8043 \
        -O srm-util-stub-server-1_1.SecureProtocol=gsi \
        -O srm-util-stub-server-1_1.PoolLocation=${MODULE_TEST_DIR}/var/tmp/srm/pool \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-1.1.log \
        -O log.Priority=DEBUG
}

# Create configuration for SRM 2.2 Server Stub 
test_agents_srm_stub_server_2_2_install__DEPENDS="init_unit_test"
function test_agents_srm_stub_server_2_2_install(){

    # Create Template for the SRM 1.1 Stub 
    create_config_xml "glite-srm-util-stub-server-2_2" ${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-2.2.config.xml \
        ${SRM_UTIL_CPP_TEST_DIR}/config/srm-util-stub-server-2.2.config-template.xml
    # Create configuration for SRM 2.2 Stub 
    config_generator -f ${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-2.2.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-2.2.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-2.2.log-properties \
        -O srm-util-stub-server-2_2.Port=8044 \
        -O srm-util-stub-server-2_2.SecureProtocol=gsi \
        -O srm-util-stub-server-2_2.PoolLocation=${MODULE_TEST_DIR}/var/tmp/srm/pool \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-2.2.log \
        -O log.Priority=DEBUG
}

# Create configuration for SRM 2.2 Server Stub for the SRMCopy channel
test_agents_srm_stub_server_srmcopy_2_2_install__DEPENDS="init_unit_test"
function test_agents_srm_stub_server_srmcopy_2_2_install(){

    # Create Template for the SRM 1.1 Stub 
    create_config_xml "glite-srm-util-stub-server-srmcopy-2_2" \
        ${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-2.2.config.xml \
        ${SRM_UTIL_CPP_TEST_DIR}/config/srm-util-stub-server-2.2.config-template.xml
    # Create configuration for SRM 2.2 Stub 
    config_generator -f ${MODULE_TEST_DIR}/config/glite-srm-util-stub-server-2.2.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-srmcopy-2.2.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-srm-util-stub-server-srmcopy-2.2.log-properties \
        -O srm-util-stub-server-2_2.Port=8045 \
        -O srm-util-stub-server-2_2.SecureProtocol=gsi \
        -O srm-util-stub-server-2_2.PoolLocation=${MODULE_TEST_DIR}/var/tmp/srm/pool \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-srmcopy-2.2.log \
        -O log.Priority=DEBUG
}

    
 # Start Stub servers 
agents_start_stub_servers__DEPENDS="init_unit_test test_agents_srm_stub_server_1_1_install test_agents_srm_stub_server_2_2_install test_agents_srm_stub_server_srmcopy_2_2_install"
function agents_start_stub_servers(){
    # Kill Previous errors 
    killall glite_data_config_service
    sleep 1
    killall glite_data_config_service
    sleep 5
    info "Starting SRM Stub servers"
    # Start the SRM 1.1 Stub
    debug "Starting SRM 1.1 Stub..."
    (cd ${GLITE_LOCATION}/bin && env \
        GLITE_LOCATION="${MODULE_TEST_DIR}" \
        X509_VOMS_DIR="${HOST_X509_VOMS_DIR}" \
        X509_USER_KEY="${HOST_X509_USER_KEY}" \
        X509_USER_CERT="${HOST_X509_USER_CERT}" \
        CGSI_TRACE=${TESTS_CGSI_TRACE} \
        CGSI_TRACEFILE="${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-1.1.cgsi" \
        ${GLITE_LOCATION}/bin/glite_data_config_service ${CONFIG_SERVICE_FLAGS} glite-srm-util-stub-server-1.1 start) || {
            error "Could not start SRM 1.1 Stub" 
            return 1
    }
    #config_service glite-srm-util-stub-server-1.1 start || return ${?}
    debug "SRM 1.1 Stub Started"
    # start SRM2.2 stub
    debug "Starting SRM 2.2 Stub..."
    (cd ${GLITE_LOCATION}/bin && env \
        GLITE_LOCATION="${MODULE_TEST_DIR}" \
        X509_VOMS_DIR="${HOST_X509_VOMS_DIR}" \
        X509_USER_KEY="${HOST_X509_USER_KEY}" \
        X509_USER_CERT="${HOST_X509_USER_CERT}" \
        CGSI_TRACE=${TESTS_CGSI_TRACE} \
        CGSI_TRACEFILE="${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-2.2.cgsi" \
        ${GLITE_LOCATION}/bin/glite_data_config_service ${CONFIG_SERVICE_FLAGS} glite-srm-util-stub-server-2.2 start) || {
            error "Could not start SRM 2.2 Stub" 
            return 1
    }
    #config_service glite-srm-util-stub-server-2.2 start || return ${?}
    debug "SRM 2.2 Stub Started"
    # start SRM2.2 stub for SRMCopy channel
    debug "Starting SRM 2.2 Stub for SRMCopy channel..."
    (cd ${GLITE_LOCATION}/bin && env \
        GLITE_LOCATION="${MODULE_TEST_DIR}" \
        X509_VOMS_DIR="${HOST_X509_VOMS_DIR}" \
        X509_USER_KEY="${HOST_X509_USER_KEY}" \
        X509_USER_CERT="${HOST_X509_USER_CERT}" \
        CGSI_TRACE=${TESTS_CGSI_TRACE} \
        CGSI_TRACEFILE="${MODULE_TEST_DIR}/var/log/glite-srm-util-stub-server-srmcopy-2.2.cgsi" \
        ${GLITE_LOCATION}/bin/glite_data_config_service ${CONFIG_SERVICE_FLAGS} glite-srm-util-stub-server-srmcopy-2.2 start) || {
            error "Could not start SRM 2.2 Stub for SRMCopy channel" 
            return 1
    }
    #config_service glite-srm-util-stub-server-2.2 start || return ${?}
    debug "SRM 2.2 Stub for SRMCopy channel Started"
}

function agents_stop_stub_servers(){
    info "Stopping SRM Stub servers"
    debug "Stopping SRM 2.2 Stub for SRMCopy channel..."
    config_service glite-srm-util-stub-server-srmcopy-2.2 stop
    debug "SRM 2.2 Stub for SRMCopy channel Stopped."
    debug "Stopping SRM 2.2 Stub..."
    config_service glite-srm-util-stub-server-2.2 stop
    debug "SRM 2.2 Stub Stopped."
    debug "Stopping SRM 1.1 Stub..."
    config_service glite-srm-util-stub-server-1.1 stop
    debug "SRM 1.1 Stub Stopped."
}

# create a test file in the SRM pool
function create_test_file(){
    dd if=/dev/zero of=${MODULE_TEST_DIR}/var/tmp/srm/pool/stub/home/dteam/tmp/${1} bs=1024 count=1024 > /dev/null 2>&1
}

# Agents Unit Test 
test_agents_ora__DEPENDS="test_agents_ora_install"
function test_agents_ora(){

    #/c Kill Previous errors 
    killall glite_data_config_service
    sleep 1
    killall glite_data_config_service
    sleep 1
    killall glite_data_config_service
    sleep 1
    killall glite_data_config_service
    sleep 1
    rm -rf /tmp/x509up_dn*
    rm -rf /tmp/x509up_h*
    # Delete Pools 
    rm -rf ${MODULE_TEST_DIR}/var/tmp/srm/pool
    # Create Pools 
    mkdir -p ${MODULE_TEST_DIR}/var/tmp/srm/pool/stub/home/dteam/tmp/
    # Create Source files for the test 
    create_test_file src00.dat
    create_test_file src01.dat
    create_test_file src02.dat
    # Create Source files for the test (SRMCOPY channel)
    create_test_file srm00.dat
    create_test_file srm01.dat
    create_test_file srm02.dat
    create_test_file srm03.dat
    create_test_file srm04.dat
    create_test_file srm05.dat
    create_test_file srm06.dat
    create_test_file this-one-returns-SRM_DUPLICATION_ERROR-on-copy.dat
    # Start Stub Servers 
    run_test_function agents_start_stub_servers || return ${?}
    sleep 3

    # Start the agents; not using the "config_service" function because of non
    # default values of environment variables.
    info "Starting VO and Channel Agents..." 
    debug "Starting VO Agent..."
    (cd ${GLITE_LOCATION}/bin && env GLITE_LOCATION="${MODULE_TEST_DIR}" \
        X509_USER_KEY="${HOST_X509_USER_KEY}" \
        X509_USER_CERT="${HOST_X509_USER_CERT}" \
        ${GLITE_LOCATION}/bin/glite_data_config_service ${CONFIG_SERVICE_FLAGS} \
            glite-transfer-agent-test-agents-vo-ora start) || {
                error "VO Agent failed to start" 
                return 1
            } 
    debug "VO Agent Started"
    debug "Starting Channel Agent 1..."
    
    echo "${MODULE_TEST_DIR}"
    echo "${GLITE_LOCATION}"
    
    (cd ${GLITE_LOCATION}/bin && env GLITE_LOCATION="${MODULE_TEST_DIR}" \
        ${GLITE_LOCATION}/bin/glite_data_config_service -v ${CONFIG_SERVICE_FLAGS} \
            glite-transfer-agent-test-agents-channel1-ora start) || {
                error "Channel Agent 1 failed to start" 
                return 1
            }    
    debug "Channel Agent 1 Started"
    sleep 1
    debug "Starting Channel Agent 2..."
    (cd ${GLITE_LOCATION}/bin && env GLITE_LOCATION="${MODULE_TEST_DIR}" \
        ${GLITE_LOCATION}/bin/glite_data_config_service ${CONFIG_SERVICE_FLAGS} \
            glite-transfer-agent-test-agents-channel2-ora start) || {
                error "Channel Agent 2 failed to start" 
                return 1
            } 
    debug "Channel Agent 2 Started"
    sleep 1
    debug "Starting Channel Agent 3..."
    (cd ${GLITE_LOCATION}/bin && env GLITE_LOCATION="${GLITE_LOCATION}" \
        GLITE_LOCATION_USER="${MODULE_TEST_DIR}" \
        GLITE_SD_SERVICES_XML="${MODULE_TEST_DIR}/etc/services.xml" \
        X509_USER_KEY="${HOST_X509_USER_KEY}" \
        X509_USER_CERT="${HOST_X509_USER_CERT}" \
        CGSI_TRACE=${TESTS_CGSI_TRACE} \
        CGSI_TRACEFILE="${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-agents-channel-urlcopy-oracle.cgsi" \
        ${GLITE_LOCATION}/bin/glite_data_config_service ${CONFIG_SERVICE_FLAGS} \
        glite-transfer-agent-test-agents-channel3-ora start) || {
                error "Channel Agent 3 failed to start" 
                return 1
            } 
    debug "Channel Agent 3 Started"
    sleep 1

    debug "Starting Channel Agent 4..."
    (cd ${GLITE_LOCATION}/bin && env GLITE_LOCATION="${GLITE_LOCATION}" \
        GLITE_LOCATION_USER="${MODULE_TEST_DIR}" \
        GLITE_SD_SERVICES_XML="${MODULE_TEST_DIR}/etc/services.xml" \
        X509_USER_KEY="${HOST_X509_USER_KEY}" \
        X509_USER_CERT="${HOST_X509_USER_CERT}" \
        CGSI_TRACE=${TESTS_CGSI_TRACE} \
        CGSI_TRACEFILE="${MODULE_TEST_DIR}/var/log/glite-transfer-agent-test-agents-channel-urlcopy-oracle.cgsi" \
        ${GLITE_LOCATION}/bin/glite_data_config_service ${CONFIG_SERVICE_FLAGS} \
            glite-transfer-agent-test-agents-channel4-ora start) || {
                error "Channel Agent 4 failed to start" 
                return 1
            }
    debug "Channel Agent 4 Started"
    sleep 1
    
    # Run the Unit Test 
    info "Processing..."
    (cd ${MODULE_TEST_DIR}/bin && ${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_agents \
        -l ${MODULE_TEST_DIR} -c glite-transfer-agent-test-agents-ora -s)
    local res=${?}
    sleep 1
    
    info "Stopping VO and Channel Agents" 
    # Stop the Channel Agent 4 
    debug "Stopping Channel Agent 4..."
    config_service glite-transfer-agent-test-agents-channel4-ora stop
    debug "Channel Agent 4 Stopped."
    # Stop the Channel Agent 3 
    debug "Stopping Channel Agent 3..."
    config_service glite-transfer-agent-test-agents-channel3-ora stop
    debug "Channel Agent 3 Stopped."
    # Stop the Channel Agent 2 
    debug "Stopping Channel Agent 2..."
    config_service glite-transfer-agent-test-agents-channel2-ora stop
    debug "Channel Agent 2 Stopped."
    # Stop the Channel Agent 1 
    debug "Stopping Channel Agent 1..."
    config_service glite-transfer-agent-test-agents-channel1-ora stop
    debug "Channel Agent 1 Stopped."
    # Stop the VO Agent 
    debug "Stopping VO Agent..."
    config_service glite-transfer-agent-test-agents-vo-ora stop
    debug "VO Agent Stopped."

    rm -rf /tmp/x509up_dn*
    rm -rf /tmp/x509up_h*

    rm -rf ${MODULE_TEST_DIR}/bin/ts-stub__*
    # Stop Stub Servers
    run_test_function agents_stop_stub_servers
    # Delete Pools 
    rm -rf ${MODULE_TEST_DIR}/var/tmp/srm/pool

    return ${res}
}
     
# Install Scheduler UnitTest Data
test_agents__DEPENDS="test_agents_ora"
function test_agents(){
    true
}
