#
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
#  Test script for checking the Python Catalog plugin
#
#  Authors: Paolo Badino <paolo.badino@cern.ch>
#           Paolo Tedesco <paolo.tedesco@cern.ch>
#  Version info: $Id: TestCatalog.py,v 1.6 2008/11/17 10:17:39 ptedesco Exp $
#  Release: $Name:  $
#

import re
import glite.data.agents.utils
import glite.fts.catalog

#
# Declare Constants used in the script
#
MODULE_NAME      = "test_catalog"

# Log Functions
DebugPriority = glite.data.agents.utils.LogPriority.Debug
def m_log_debug(msg):
    global DebugPriority 
    glite.data.agents.utils.Log(MODULE_NAME,DebugPriority,msg)
    
def m_log_info(msg):
    glite.data.agents.utils.LogInfo(MODULE_NAME,msg)

def m_log_warn(msg):
    glite.data.agents.utils.LogWarn(MODULE_NAME,msg)

def m_log_error(msg):
    glite.data.agents.utils.LogError(MODULE_NAME,msg)

#
# Declare the CatalogPlugin Version supported by this script
#
def CatalogPluginVersion():
    return "1.0"

#
# Init Plugin
#
def InitCatalogPlugin(params):
    m_log_info("CatalogPlugin initialized")
    return True;

#
# Global Catalog Type
#
def GlobalCatalogType():
    return "TestPythonCatalog"

#
# Local Catalog Type
#
def LocalCatalogType():
    return "TestLocalPythonCatalog"

#
# Get Catalog Endpoint
#
def GetEndpoint(site,vo_name):
    result = glite.fts.catalog.StringPair()
    
    #Get Fake Catalog Endpoint
    if(len(site) > 0):
        result.First  = ("test://catalog@%s:1234/local" % (site)) ;
        result.Second = LocalCatalogType();
    else:
        result.First  = "test://localhost:1234/global";
        result.Second = GlobalCatalogType();
        
    return result
    
#
# Check if the given name is valid
#
def IsValid(name):
    exp = re.compile(r'(.*)fail(.*)')
    exp_remote = re.compile(r'(.*)failremote(.*)')
    if exp.search( name ):
        if exp_remote.search( name ):
            glite.fts.catalog.RaiseRemoteError('No contact')
        ret = False
    else:
        ret = True
    return ret

#
# SURLS Map
#    
g_Surls = dict();
    
#
# Define TestCatalogStat class
#
class TestCatalogStat(glite.fts.catalog.FileStat):
    # Stat Data
    Data = "<empty>"
    # Test Function
    def test(self):
        print "Stat for file <%s>:" % (self.Logical)
        print "Data: %s" % (self.Data)

################################################################################

#
# CheckPermissions
#
def CheckPermissions(endpoint,type,names):
    m_log_debug("entering CheckPermissions(%s:%s)" % (endpoint,type))

    result = glite.fts.catalog.CatalogResult()
    result.Status = glite.fts.catalog.ResultStatus.Success
    
    # For each name, check it's permissions
    for name in names:
        m_log_debug("Checking file %s" % name)
        if((False == IsValid(name)) or (False == g_Surls.has_key(name))):
            result.Status = glite.fts.catalog.ResultStatus.SomeFailures
            result.Failures.append(glite.fts.catalog.StringPair(name,"The file doesn't exist"))
            m_log_error("%s : DENY" % name)
        else:
            m_log_info("%s : GRANTED" % name)
            
    if(glite.fts.catalog.ResultStatus.Success != result.Status):
        result.Reason = "Some Errors in CheckPermissions"
        
    m_log_debug("leaving CheckPermissions")
    return result;

#
# ListSurls
#    
def ListSurls(endpoint,type,names,source):
    m_log_debug("entering ListSurls(%s:%s)" % (endpoint,type))
   
    global g_Surls
    
    result = glite.fts.catalog.ListSurlsResult()
    result.Status = glite.fts.catalog.ResultStatus.Success

    # For Each name
    for name in names:
        m_log_debug("Getting SURLs for LFN <%s> at <%s>" % (name,source))
        a = glite.fts.catalog.StringArray()
        if(True == g_Surls.has_key(name)):
            for s in g_Surls[name]:
                # Add Surls to the List
                a.append(s)
                m_log_info("Got %s:%s" % (name,s))
        else:
            result.Status = glite.fts.catalog.ResultStatus.SomeFailures
            result.Failures.append(glite.fts.catalog.StringPair(name,"The file doesn't exist"))
            m_log_error("%s NOT EXISTING" % (name))
        
        result.Surls.append(a)

    if(glite.fts.catalog.ResultStatus.Success != result.Status):
        result.Reason = "Some Errors in ListSurls"
    
    m_log_debug("leaving ListSurls")
    return result
   
#
# CheckSurls
#
def CheckSurls(endpoint,type,names):
    m_log_debug("entering CheckSurls(%s:%s)" % (endpoint,type))
   
    global g_Surls
    
    result = glite.fts.catalog.CatalogResult()
    result.Status = glite.fts.catalog.ResultStatus.Success

    # For Each name
    for name in names:
        logical = name.First
        surl    = name.Second 
        m_log_debug("Checking SURL <%s> for LFN <%s>" % (surl,logical))
        if(True == g_Surls.has_key(logical)):
            if(surl in g_Surls[logical]):
                # Surls already exist
                result.Status = glite.fts.catalog.ResultStatus.SomeFailures
                result.Failures.append(glite.fts.catalog.StringPair(logical,"The file already exists"))
                m_log_error("<%s:%s> ALREADY EXISTS" % (logical,surl))
            else:
                m_log_info("<%s:%s> doesn't exit" % (logical,surl))
        else:
            m_log_warn("%s doesn't exit" % (logical))
        
    if(glite.fts.catalog.ResultStatus.Success != result.Status):
        result.Reason = "Some Errors in CheckSurls"
    
    m_log_debug("leaving CheckSurls")
    return result
 
#
# GetStats
#    
def GetStats(endpoint,type,names):
    m_log_debug("entering GetStats(%s:%s)" % (endpoint,type))
   
    global g_Surls
    
    result = glite.fts.catalog.GetStatsResult()
    result.Status = glite.fts.catalog.ResultStatus.Success

    # For Each name
    for name in names:
        logical = name.First
        surl    = name.Second 
        m_log_debug("Getting Stats for LFN <%s> SURL <%s>" % (logical,surl))
        if(True == g_Surls.has_key(logical)):
            if(surl in g_Surls[logical]):
                # Add Stats to the list
                s = TestCatalogStat()
                s.Logical = logical
                s.Data    = "Internal file data"
                result.Stats.append(s)
                m_log_info("Got Stat for <%s:%s>" % (logical,surl))
            else:
                result.Stats.append(None)
                result.Status = glite.fts.catalog.ResultStatus.SomeFailures
                result.Failures.append(glite.fts.catalog.StringPair(logical,"The surl doesn't exist"))
                m_log_error("<%s:%s> NOT EXISTING" % (logical,surl))
        else:
            result.Stats.append(None)
            result.Status = glite.fts.catalog.ResultStatus.SomeFailures
            result.Failures.append(glite.fts.catalog.StringPair(logical,"The file doesn't exist"))
            m_log_error("%s NOT EXISTING" % (logical))
        
    if(glite.fts.catalog.ResultStatus.Success != result.Status):
        result.Reason = "Some Errors in ListSurls"
    
    m_log_debug("leaving GetStats")
    return result
 
#
# RegisterSurls
#
def RegisterSurls(endpoint,type,replicas):
    m_log_debug("entering RegisterSurls(%s:%s)" % (endpoint,type))
    
    global g_Surls
    
    result = glite.fts.catalog.CatalogResult()
    result.Status = glite.fts.catalog.ResultStatus.Success

    # For Each name
    for r in replicas:
        m_log_debug("Registering SURL <%s> for LFN <%s>" % (r.Surl,r.Logical))
        if(False == IsValid(r.Logical)):
            result.Status = glite.fts.catalog.ResultStatus.SomeFailures
            result.Failures.append(glite.fts.catalog.StringPair(r.Logical,"The file doesn't exists"))
            m_log_error("%s:%s REGISTRATION FAILED" % (r.Logical, r.Surl))
        else:
            # Check Stat
            stat = r.Stat
            if(stat is not None):
                m_log_debug("%s has stat" % (r.Logical))
                # should be a TestCatalogStat
                m_log_debug("Stat is %s" % (str(stat)))
                stat.test()
            else :
                m_log_debug("%s have no stat" % (r.Logical))
            if(False == g_Surls.has_key(r.Logical)):
                g_Surls[r.Logical] = list()
                g_Surls[r.Logical].append(r.Surl)
                m_log_info("%s:%s REGISTERED" % (r.Logical, r.Surl))
            else:
                # Check if the Surls Already Exists
                if(r.Surl in g_Surls[r.Logical]):
                    m_log_info("%s:%s already registered" % (r.Logical, r.Surl))
                else:
                    g_Surls[r.Logical].append(r.Surl)
                    m_log_info("%s:%s REGISTERED" % (r.Logical, r.Surl))

    if(glite.fts.catalog.ResultStatus.Success != result.Status):
        result.Reason = "Some Errors in RegisterSurls"

    m_log_debug("leaving RegisterSurls")
    return result

if __name__ == "__main__":
    print "Catalog Plugin Version %s" % CatalogPluginVersion()
    print "GlobalCatalogType      %s" % GlobalCatalogType()
    print "LocalCatalogType       %s" % LocalCatalogType()

    InitCatalogPlugin("")

    # Get Endpoint
    GetEndpoint("CERN","VO1")
    GetEndpoint("","VO1")
    
    # CheckPermissions
    names = glite.fts.catalog.StringArray();
    names.append("lfn:///tmp/test/lfn-01.txt")
    names.append("lfn:///tmp/test/lfn-02.txt")
    result = CheckPermissions("fake_endpoint","fake_type",names)
    names.append("/fail/test/this-should-fail.txt")
    result = CheckPermissions("fake_endpoint","fake_type",names)

    # RegisterSurls
    replicas = glite.fts.catalog.ReplicaStatArray();
    replicas.append(glite.fts.catalog.ReplicaStat("lfn:///tmp/test/lfn-01.txt","srm://castor.cern.ch:8443/srm/managerv1?SFN=/tmp/test/lfn-01.txt"))
    replicas.append(glite.fts.catalog.ReplicaStat("lfn:///tmp/test/lfn-02.txt","srm://castor.cern.ch:8443/srm/managerv1?SFN=/tmp/test/lfn-02.txt"))

    result = RegisterSurls("fake_endpoint","fake_type",replicas)
    replicas.append(glite.fts.catalog.ReplicaStat("/fail/test/this-should-fail.txt","srm://castor.cern.ch:8443/srm/managerv1?SFN=/fail/test/this-should-fail.txt"))
    result = RegisterSurls("fake_endpoint","fake_type",replicas)

    # CheckSurls
    names = glite.fts.catalog.StringPairArray();
    names.append(glite.fts.catalog.StringPair("lfn:///tmp/test/lfn-98.txt","srm://castor.cern.ch:8443/srm/managerv1?SFN=/tmp/test/lfn-98.txt"))
    names.append(glite.fts.catalog.StringPair("lfn:///tmp/test/lfn-02.txt","srm://castor.cern.ch:8443/srm/managerv1?SFN=/tmp/test/lfn-99.txt"))
    result = CheckSurls("fake_endpoint","fake_type",names)
    names.append(glite.fts.catalog.StringPair("lfn:///tmp/test/lfn-01.txt","srm://castor.cern.ch:8443/srm/managerv1?SFN=/tmp/test/lfn-01.txt"))
    result = CheckSurls("fake_endpoint","fake_type",names)

    # ListSurls
    names = glite.fts.catalog.StringArray();
    names.append("lfn:///tmp/test/lfn-01.txt")
    names.append("lfn:///tmp/test/lfn-02.txt")
    result = ListSurls("fake_endpoint","fake_type",names,"localhost")
    names.append("/fail/test/this-should-fail.txt")
    result = ListSurls("fake_endpoint","fake_type",names,"localhost")

    # GetStats
    names = glite.fts.catalog.StringPairArray();
    names.append(glite.fts.catalog.StringPair("lfn:///tmp/test/lfn-01.txt","srm://castor.cern.ch:8443/srm/managerv1?SFN=/tmp/test/lfn-01.txt"))
    names.append(glite.fts.catalog.StringPair("lfn:///tmp/test/lfn-02.txt","srm://castor.cern.ch:8443/srm/managerv1?SFN=/tmp/test/lfn-02.txt"))
    result = GetStats("fake_endpoint","fake_type",names)
    for s in result.Stats:
        if s is not None:
            s.test()
    names.append(glite.fts.catalog.StringPair("/fail/test/this-should-fail.txt","srm://castor.cern.ch:8443/srm/managerv1?SFN=/fail/test/this-should-fail.txt"))
    result = GetStats("fake_endpoint","fake_type",names)
    
    print "Done"
