#!/bin/bash
# Copyright (c) Members of the EGEE Collaboration. 2004.
# See http://www.eu-egee.org/partners/ for details on the copyright holders.
# 
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# 
#     http://www.apache.org/licenses/LICENSE-2.0
# 
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Install SD stub Target 
function test_catalog_sd_stub_install(){
    # Create services.xml 
    cat > ${MODULE_TEST_DIR}/etc/services.xml << EOD
<services>
  <service name="Test_Catalog">
    <parameters>
      <endpoint>test://localhost:666</endpoint>
      <type>TestPythonCatalog</type>
      <version>0.0.0</version>
    </parameters>
  </service>
  <service name="Stub_Catalog_CERN">
    <parameters>
      <endpoint>test://localhost:1234</endpoint>
      <type>TestLocalPythonCatalog</type>
      <version>0.0.0</version>
      <site>CERN</site>
    </parameters>
  </service>
</services>
EOD
}

# Install Python Stub UnitTest Data
TEST_CATALOG_PYTHON_PACKAGES_DIR=""
test_catalog_python_install__DEPENDS="init_unit_test test_catalog_sd_stub_install"
function test_catalog_python_install(){

    # Create Template for the UnitTest 
    create_config_xml "glite-transfer-agent-test-catalog-python" ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-catalog-python.config.xml \
        ${AGENTS_COMMON_CONFIG_TEMPLATES}/agents-python.config-template.xml \
        ${MODULE_CONFIG_TEMPLATES}/transfer-agent-catalog-python.config-template.xml
    # Python Path 
    TEST_CATALOG_PYTHON_PACKAGES_DIR=`python -c "from distutils import sysconfig; print sysconfig.get_python_lib(1,0,prefix='${GLITE_LOCATION}')"`
    # Copy Python test 
    cp ${MODULE_DIR}/test/catalog/python/scripts/TestCatalog.py ${MODULE_TEST_DIR}/bin

    # Create UnitTest configuration                                   
    config_generator -f ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-catalog-python.config.xml \
        -o ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-catalog-python.properties.xml \
        -l ${MODULE_TEST_DIR}/etc/glite-transfer-agent-test-catalog-python.log-properties \
        -O agents-python.PythonPath=${TEST_CATALOG_PYTHON_PACKAGES_DIR}:${MODULE_TEST_DIR}/bin \
        -O transfer-agent-catalog-python.CatalogModule=TestCatalog \
        -O log.fileName=${MODULE_TEST_DIR}/var/log/transfer-agent-test-catalog-python.log \
        -O log.Priority=DEBUG
}
    
# Python Unit Test 
test_catalog_python__DEPENDS="test_catalog_python_install"
function test_catalog_python(){
    (cd ${MODULE_TEST_DIR}/bin && ${MODULE_TEST_DIR}/bin/glite_data_transfer_agent_test_catalog \
        -l ${MODULE_TEST_DIR} -c glite-transfer-agent-test-catalog-python -e fake-endpoint -s) || return ${?}
}
    
test_catalog__DEPENDS="test_catalog_python"
function test_catalog(){
    true
}
