/**
 *  Copyright (c) Members of the EGEE Collaboration. 2004.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  GLite Data Transfer Agents: populate channel table script
 *
 *  Authors: Paolo Badino <paolo.badino@cern.ch>, Paolo Tedesco <paolo.tedesco@cern.ch>
 *  Version info: $Id: ora_t_channel_insert.sql,v 1.19 2008/12/04 08:53:30 ptedesco Exp $
 *  Release: $Name:  $
 *
 */
DECLARE
--------------------------------------------------------------------------------
-- Insert Channel Procedure
--------------------------------------------------------------------------------
PROCEDURE test_create_channel(
                            n    T_CHANNEL.CHANNEL_NAME%TYPE,
                            src  T_CHANNEL.SOURCE_SITE%TYPE,
                            dst  T_CHANNEL.DEST_SITE%TYPE,
                            st   T_CHANNEL.CHANNEL_STATE%TYPE,
                            s    T_CHANNEL.NOSTREAMS%TYPE, 
                            f    T_CHANNEL.NOFILES%TYPE,
                            sel  T_CHANNEL.SE_LIMIT%TYPE DEFAULT NULL,
                            cht  T_CHANNEL.CHANNEL_TYPE%TYPE DEFAULT NULL)
IS                            
BEGIN
    INSERT INTO t_channel(channel_name,source_site,dest_site,channel_state,nostreams,nofiles,se_limit,channel_type)
        VALUES (n,src,dst,st,s,f,sel,cht);
END;

--------------------------------------------------------------------------------
-- Insert Channel Procedure (3.1.0 specific properties)
--------------------------------------------------------------------------------
PROCEDURE test_create_channel_3_1_0(
    channel_name        T_CHANNEL.CHANNEL_NAME%TYPE,
    source_site         T_CHANNEL.SOURCE_SITE%TYPE,
    dest_site           T_CHANNEL.DEST_SITE%TYPE,
    blocksize           T_CHANNEL.BLOCKSIZE%TYPE,
    http_to             T_CHANNEL.HTTP_TO%TYPE,
    tx_loglevel         T_CHANNEL.TX_LOGLEVEL%TYPE,
    urlcopy_put_to      T_CHANNEL.URLCOPY_PUT_TO%TYPE,
    urlcopy_putdone_to  T_CHANNEL.URLCOPY_PUTDONE_TO%TYPE,
    urlcopy_get_to      T_CHANNEL.URLCOPY_GET_TO%TYPE,
    urlcopy_getdone_to  T_CHANNEL.URLCOPY_GETDONE_TO%TYPE,
    urlcopy_tx_to       T_CHANNEL.URLCOPY_TX_TO%TYPE,
    urlcopy_txmarks_to  T_CHANNEL.URLCOPY_TXMARKS_TO%TYPE,
    srmcopy_direction   T_CHANNEL.SRMCOPY_DIRECTION%TYPE,
    srmcopy_to          T_CHANNEL.SRMCOPY_TO%TYPE,
    srmcopy_refresh_to  T_CHANNEL.SRMCOPY_REFRESH_TO%TYPE)
IS                            
BEGIN
    INSERT INTO t_channel(channel_name,channel_state,source_site,dest_site,
        blocksize,http_to,tx_loglevel,urlcopy_put_to,urlcopy_putdone_to,
        urlcopy_get_to,urlcopy_getdone_to,urlcopy_tx_to,urlcopy_txmarks_to,
        srmcopy_direction,srmcopy_to,srmcopy_refresh_to)
    VALUES (
        channel_name,'Active',source_site,dest_site,blocksize,http_to,
        tx_loglevel,urlcopy_put_to,urlcopy_putdone_to,urlcopy_get_to,
        urlcopy_getdone_to,urlcopy_tx_to,urlcopy_txmarks_to,srmcopy_direction,
        srmcopy_to,srmcopy_refresh_to);
END;

--------------------------------------------------------------------------------
-- Insert Channel Procedure (3.2.0 specific properties)
--------------------------------------------------------------------------------
PROCEDURE test_create_channel_3_2_0(
    channel_name                T_CHANNEL.CHANNEL_NAME%TYPE,
    source_site                 T_CHANNEL.SOURCE_SITE%TYPE,
    dest_site                   T_CHANNEL.DEST_SITE%TYPE,
    target_dir_check            T_CHANNEL.TARGET_DIR_CHECK%TYPE,
    url_copy_first_txmark_to    T_CHANNEL.url_copy_first_txmark_to%TYPE)
IS
BEGIN
    INSERT INTO t_channel(channel_name,channel_state,source_site,dest_site,
        target_dir_check,url_copy_first_txmark_to)
    VALUES (
        channel_name,'Active',source_site,dest_site,
        target_dir_check,url_copy_first_txmark_to);
END;

--------------------------------------------------------------------------------
-- Insert Channel Procedure (3.3.0 specific properties)
--------------------------------------------------------------------------------
PROCEDURE test_create_channel_3_3_0(
    channel_name                T_CHANNEL.CHANNEL_NAME%TYPE,
    source_site                 T_CHANNEL.SOURCE_SITE%TYPE,
    dest_site                   T_CHANNEL.DEST_SITE%TYPE,
    tx_to_per_mb                T_CHANNEL.TX_TO_PER_MB%TYPE,
    no_tx_activity_to           T_CHANNEL.NO_TX_ACTIVITY_TO%TYPE,
    preparing_files_ratio       T_CHANNEL.PREPARING_FILES_RATIO%TYPE,
    tx_type                     T_CHANNEL.TRANSFER_TYPE%TYPE)
IS
BEGIN
    INSERT INTO t_channel(channel_name,channel_state,source_site,dest_site,
        tx_to_per_mb,no_tx_activity_to,preparing_files_ratio,transfer_type)
    VALUES (
        channel_name,'Active',source_site,dest_site,
        tx_to_per_mb,no_tx_activity_to,preparing_files_ratio,tx_type);
END;

--------------------------------------------------------------------------------
-- Insert Bad SE  Procedure
--------------------------------------------------------------------------------
PROCEDURE test_create_bad_se(
                            n    T_BAD_SES.SE_HOSTNAME%TYPE,
                            m    T_BAD_SES.MESSAGE%TYPE,
                            dn   T_BAD_SES.ADMIN_DN%TYPE)
IS                            
BEGIN
    INSERT INTO t_bad_ses(se_hostname,message,admin_dn,addition_time)
        VALUES (n,m,dn,SYSTIMESTAMP);
END;

--------------------------------------------------------------------------------
-- Main
--------------------------------------------------------------------------------
BEGIN
	-- Set Records
	test_create_channel('channel_1'         ,'cern.ch'  ,'ral.ac.uk','Active'  ,1,100);
	test_create_channel('channel_2'         ,'cern.ch'  ,'nikhef.nl','Drain'   ,2,200);
    test_create_channel('channel_3'         ,'cern.ch'  ,'infn.it'  ,'Inactive',3,300);
    test_create_channel('channel_4'         ,'cern.ch'  ,'in2p3.fr' ,'Stopped' ,4,400);
    test_create_channel('channel_5'         ,'cern.ch'  ,'*'        ,'Halted'  ,5,500);
    test_create_channel('channel_6'         ,'*'        ,'*'        ,'Active'  ,6,600);
    test_create_channel('channel_7'         ,'a'        ,'b'        ,'Inactive',7,700);
    test_create_channel('channel_8'         ,'cern.ch'  ,'desy.de'  ,'Halted'  ,8,800);
    test_create_channel('channel_9'         ,'cern.ch'  ,'unl.edu'  ,'Archived',9,900);
    test_create_channel('channel_10'        ,'cern.ch'  ,'fnal.gov' ,'Active'  ,10,1000);
    test_create_channel('channel_11'        ,'c'        ,'d'        ,'Active'  ,11,1100,12,'DEDICATED');
    test_create_channel('channel_12'        ,'c'        ,'*'        ,'Active'  ,12,1200,5 ,'NONDEDICATED');
    test_create_channel('FILE_channel_1'    ,'f.cern.ch','ral.ac.uk','Active'  ,1,100);
    test_create_channel('FILE_channel_2'    ,'f.cern.ch','nikhef.nl','Drain'   ,2,200);
    test_create_channel('FILE_channel_3_SEL','source.cern.ch','*'   ,'Active'  ,4,2);
    test_create_channel('JOB_channel_1'     ,'j.cern.ch','ral.ac.uk','Active'  ,1,100);
    test_create_channel('JOB_channel_2'     ,'j.cern.ch','nikhef.nl','Drain'   ,2,200);
    test_create_channel('CREDJOB_channel_1' ,'k.cern.ch','ral.ac.uk','Active'  ,1,100);
    test_create_channel('TRANSFER_channel_1','t.cern.ch','ral.ac.uk','Active'  ,1,100);
    test_create_channel('TRANSFER_channel_2','t.cern.ch','nikhef.nl','Drain'   ,2,200);
    test_create_channel('STAGEREQ_channel_1','sr.cern.ch','ral.ac.uk','Active' ,1,100);
    test_create_channel('STAGEREQ_channel_2','sr.cern.ch','nikhef.nl','Active' ,2,200);
    test_create_channel('CRED_channel_1'    ,'c.cern.ch','nikhef.nl' ,'Active' ,1,100);
   
    -- GetShare tests and refactoring 
    test_create_channel('GETSHARE_channel_1','GETSHARE_1','GETSHARE_1','Active' ,1,50);
    test_create_channel('GETSHARE_channel_2','GETSHARE_2','GETSHARE_2','Active' ,1,200);
    test_create_channel('GETSHARE_channel_3','GETSHARE_3','GETSHARE_3','Active' ,1,100);
    test_create_channel('GETSHARE_channel_4','GETSHARE_4','GETSHARE_4','Active' ,1,10);
    test_create_channel('GETSHARE_channel_5','GETSHARE_5','GETSHARE_5','Active' ,1,100);
    
    -- 3.1.0 Records
	test_create_channel_3_1_0('channel_20','x','y','1 MB',10,'DEBUG',20,30,40,50,60,70,'PUSH',80,90);
    test_create_channel_3_1_0('channel_23','x_23','y_23','0',-1,'INFO',-1,-1,-1,-50,-60,-1,'PUSH',-10,-1);
    
    -- 3.2.0 Records
    test_create_channel_3_2_0('channel_21','x_21','y_21','N',5);
    test_create_channel_3_2_0('channel_22','x_22','y_22','Y',15);
     
    -- for bug specific tests
    test_create_channel('bug_channel'    ,'foo','bar' ,'Active' ,1,100);
        
    -- Blacklist SEs
    test_create_bad_se('bad.host.cern.ch','this host is faulty','My DN');
    test_create_bad_se('BAD_SITE'        ,'this site is bad'   ,'My DN');
    
    -- 3.3.0 Records
    test_create_channel_3_3_0('channel_24','x_24','y24',NULL,NULL,NULL,'URLCOPY');
    test_create_channel_3_3_0('channel_25','x_25','y25',1.1,3,2.5,'SRMCOPY');
    
END;
/
