DECLARE
-- Insert Job Procedure
PROCEDURE test_create_job(
                            j    T_JOB.JOB_ID%TYPE,
                            st   T_JOB.JOB_STATE%TYPE,
                            dn   T_JOB.USER_DN%TYPE, 
                            cr   T_JOB.USER_CRED%TYPE,
                            vo   T_JOB.VO_NAME%TYPE, 
                            ch   T_JOB.CHANNEL_NAME%TYPE,
                            src  T_JOB.SOURCE%TYPE, 
                            dst  T_JOB.DEST%TYPE,
                            sh   T_JOB.SUBMIT_HOST%TYPE DEFAULT NULL,
                            mtiq T_JOB.MAX_TIME_IN_QUEUE%TYPE DEFAULT NULL,
                            cj   T_JOB.CANCEL_JOB%TYPE DEFAULT NULL,
                            ci   T_JOB.CRED_ID%TYPE DEFAULT NULL,
                            sut  T_JOB.SUBMIT_TIME%TYPE DEFAULT NULL,
                            o_f  T_JOB.OVERWRITE_FLAG%TYPE DEFAULT NULL,
                            sse  T_JOB.SOURCE_SE%TYPE DEFAULT NULL,
                            dse  T_JOB.DEST_SE%TYPE DEFAULT NULL,
                            sst  T_JOB.SOURCE_SPACE_TOKEN%TYPE DEFAULT NULL,
                            sstd T_JOB.SOURCE_TOKEN_DESCRIPTION%TYPE DEFAULT NULL)
IS                            
BEGIN
    IF sut IS NULL THEN
        INSERT INTO t_job(job_id,job_state,user_dn,user_cred,cred_id,vo_name,
            channel_name,source,dest,submit_host,max_time_in_queue,cancel_job, 
            overwrite_flag, source_se,dest_se,
            source_space_token,source_token_description) 
        VALUES (j,st,dn,cr,ci,vo,
            ch,src,dst,sh,mtiq,cj,
            o_f,sse,dse,
            sst,sstd);
    ELSE 
        INSERT INTO t_job(job_id,job_state,user_dn,user_cred,cred_id,vo_name,
            channel_name,source,dest,submit_host,max_time_in_queue,cancel_job, 
            submit_time, overwrite_flag,source_se,dest_se,
            source_space_token,source_token_description) 
        VALUES (j,st,dn,cr,ci,vo,
            ch,src,dst,sh,mtiq,cj,
            sut,o_f,sse,dse,
            sst,sstd);
    END IF;            
END;

-- Insert Job with job_finished set Procedure
PROCEDURE test_create_job_finished(
                            j    T_JOB.JOB_ID%TYPE,
                            st   T_JOB.JOB_STATE%TYPE,
                            dn   T_JOB.USER_DN%TYPE, 
                            cr   T_JOB.USER_CRED%TYPE,
                            vo   T_JOB.VO_NAME%TYPE, 
                            ch   T_JOB.CHANNEL_NAME%TYPE,
                            src  T_JOB.SOURCE%TYPE, 
                            dst  T_JOB.DEST%TYPE,
                            sh   T_JOB.SUBMIT_HOST%TYPE DEFAULT NULL,
                            mtiq T_JOB.MAX_TIME_IN_QUEUE%TYPE DEFAULT NULL,
                            cj   T_JOB.CANCEL_JOB%TYPE DEFAULT NULL,
                            ci   T_JOB.CRED_ID%TYPE DEFAULT NULL,
                            sut  T_JOB.SUBMIT_TIME%TYPE DEFAULT NULL,
                            o_f  T_JOB.OVERWRITE_FLAG%TYPE DEFAULT NULL,
                            sse  T_JOB.SOURCE_SE%TYPE DEFAULT NULL,
                            dse  T_JOB.DEST_SE%TYPE DEFAULT NULL)
IS                            
BEGIN
    IF sut IS NULL THEN
        INSERT INTO t_job(
            job_id,job_state,user_dn,user_cred,cred_id,vo_name,channel_name,
            source,dest,submit_host,max_time_in_queue,cancel_job, 
            overwrite_flag, source_se,dest_se,job_finished) 
            VALUES (j,st,dn,cr,ci,vo,ch,src,dst,sh,mtiq,cj,o_f,sse,dse,CURRENT_DATE);
    ELSE 
        INSERT INTO t_job(
            job_id,job_state,user_dn,user_cred,cred_id,vo_name,channel_name,
            source,dest,submit_host,max_time_in_queue,cancel_job, 
            submit_time, 
            overwrite_flag,source_se,dest_se,job_finished) 
            VALUES (j,st,dn,cr,ci,vo,ch,src,dst,sh,mtiq,cj,sut,o_f,sse,dse,CURRENT_DATE);
    END IF;            
END;

-- Insert Job with 3.3.0 properties
PROCEDURE create_job_330(
    j    T_JOB.JOB_ID%TYPE,
    st   T_JOB.JOB_STATE%TYPE,
    dn   T_JOB.USER_DN%TYPE, 
    cr   T_JOB.USER_CRED%TYPE,
    vo   T_JOB.VO_NAME%TYPE, 
    ch   T_JOB.CHANNEL_NAME%TYPE,
    cpl  T_JOB.COPY_PIN_LIFETIME%TYPE,
    lc   T_JOB.LAN_CONNECTION%TYPE,
    fn   T_JOB.FAIL_NEARLINE%TYPE)
IS                            
BEGIN
    INSERT INTO t_job(job_id,job_state,user_dn,user_cred,vo_name,channel_name,
        copy_pin_lifetime,lan_connection,fail_nearline) 
    VALUES (j,st,dn,cr,vo,ch,cpl,lc,fn);
END;

-- Insert Job with 3.4.1 properties
PROCEDURE create_job_341(
    j    T_JOB.JOB_ID%TYPE,
    st   T_JOB.JOB_STATE%TYPE,
    dn   T_JOB.USER_DN%TYPE, 
    cr   T_JOB.USER_CRED%TYPE,
    vo   T_JOB.VO_NAME%TYPE, 
    ch   T_JOB.CHANNEL_NAME%TYPE,
    cpl  T_JOB.COPY_PIN_LIFETIME%TYPE,
    lc   T_JOB.LAN_CONNECTION%TYPE,
    fn   T_JOB.FAIL_NEARLINE%TYPE,
    cc   T_JOB.CHECKSUM_METHOD%TYPE)
IS                            
BEGIN
    INSERT INTO t_job(job_id,job_state,user_dn,user_cred,vo_name,channel_name,
        copy_pin_lifetime,lan_connection,fail_nearline,checksum_method) 
    VALUES (j,st,dn,cr,vo,ch,cpl,lc,fn,cc);
END;


-- Main
BEGIN
    -- Set Records
    test_create_job('00000000-0000-0000-0000-000000000001','Active'   ,'DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000002','Done'     ,'DN=A User','My_Cred','FILE_VO_2'    ,'FILE_channel_2'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000003','Active'   ,'DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000004','Pending'  ,'DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000005','Done'     ,'DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000006','Active'   ,'DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000007','Submitted','DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000008','Submitted','DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000009','Submitted','DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000010','Finishing','DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000011','Finishing','DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000012','Finishing','DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000013','Ready'    ,'DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000014','Active'   ,'DN=A User','My_Cred','FILE_VO_2'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000015','Ready'    ,'DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL, NULL, 'Y');
    test_create_job('00000000-0000-0000-0000-000000000016','Active'   ,'DN=A User','My_Cred','FILE_VO_2'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL, NULL, 'Y');
    test_create_job('00000000-0000-0000-0000-000000000017','Active'   ,'DN=A User','My_Cred','FILE_VO_2'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL, NULL, 'Y');
    test_create_job('00000000-0000-0000-0000-000000000018','Active'   ,'DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL, NULL, 'Y');
    test_create_job('00000000-0000-0000-0000-000000000101','Ready'    ,'DN=A User','My_Cred','FILE_VO_3_SEL','FILE_channel_3_SEL','source.cern.ch','dest.cern.ch',NULL, NULL, NULL, NULL, NULL, NULL, 'host1.cern.ch', 'host2.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000102','Ready'    ,'DN=A User','My_Cred','FILE_VO_3_SEL','FILE_channel_3_SEL','source.cern.ch','dest.cern.ch',NULL, NULL, NULL, NULL, NULL, NULL, 'host1.cern.ch', 'host2.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000103','Ready'    ,'DN=A User','My_Cred','FILE_VO_3_SEL','FILE_channel_3_SEL','source.cern.ch','dest.cern.ch',NULL, NULL, NULL, NULL, NULL, NULL, 'host1.cern.ch', 'host3.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000104','Ready'    ,'DN=A User','My_Cred','FILE_VO_3_SEL','FILE_channel_3_SEL','source.cern.ch','dest.cern.ch',NULL, NULL, NULL, NULL, NULL, NULL, 'host1.cern.ch', 'host3.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000105','Ready'    ,'DN=A User','My_Cred','FILE_VO_3_SEL','FILE_channel_3_SEL','source.cern.ch','dest.cern.ch',NULL, NULL, NULL, NULL, NULL, NULL, 'host2.cern.ch', 'host3.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000106','Ready'    ,'DN=A User','My_Cred','FILE_VO_3_SEL','FILE_channel_3_SEL','source.cern.ch','dest.cern.ch',NULL, NULL, NULL, NULL, NULL, NULL, 'host2.cern.ch', 'host3.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000107','Ready'    ,'DN=A User','My_Cred','FILE_VO_3_SEL','FILE_channel_3_SEL','source.cern.ch','dest.cern.ch',NULL, NULL, NULL, NULL, NULL, NULL, 'host2.cern.ch', 'host1.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000108','Ready'    ,'DN=A User','My_Cred','FILE_VO_3_SEL','FILE_channel_3_SEL','source.cern.ch','dest.cern.ch',NULL, NULL, NULL, NULL, NULL, NULL, 'host2.cern.ch', 'host1.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000109','Ready'    ,'DN=A User','My_Cred','FILE_VO_3_SEL','FILE_channel_3_SEL','source.cern.ch','dest.cern.ch',NULL, NULL, NULL, NULL, NULL, NULL, 'host3.cern.ch', 'host1.cern.ch');
    test_create_job('00000000-0000-0000-0000-000000000110','Ready'    ,'DN=A User','My_Cred','FILE_VO_3_SEL','FILE_channel_3_SEL','source.cern.ch','dest.cern.ch',NULL, NULL, NULL, NULL, NULL, NULL, 'host3.cern.ch', 'host1.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000001','Ready'    ,'DN=A User','My_Cred','JOB_VO_1'     ,'JOB_channel_1'     ,'source.cern.ch','dest.cern.ch','fts.cern.ch',123456);
    test_create_job('10000000-0000-0000-0000-000000000002','Pending'  ,'DN=A User','My_Cred','JOB_VO_1'     ,'JOB_channel_1'     ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000003','Pending'  ,'DN=A User','My_Cred','JOB_VO_2'     ,'JOB_channel_1'     ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000004','Pending'  ,'DN=A User','My_Cred','JOB_VO_1'     ,'JOB_channel_2'     ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000005','Submitted','DN=A User','My_Cred','JOB_VO_1'     ,'JOB_channel_1'     ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000006','Submitted','DN=A User','My_Cred','JOB_VO_2'     ,'JOB_channel_1'     ,'source.cern.ch','dest.cern.ch','fts.cern.ch',123456);
    test_create_job('10000000-0000-0000-0000-000000000007','Pending'  ,'DN=A User','My_Cred','JOB_VO_2'     ,'JOB_channel_2'     ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000008','Finishing','DN=A User','My_Cred','JOB_VO_1'     ,'JOB_channel_1'     ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000009','Submitted','DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000010','Submitted','DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000011','Done'     ,'DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000012','DoneWithErrors','DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000013','Finishing','DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000014','Finishing','DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000015','Finishing','DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000016','Finishing','DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000017','Finishing','DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000018','Pending'  ,'DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000019','Pending'  ,'DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000020','Pending'  ,'DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000021','Active'   ,'DN=A User','My_Cred','JOB_VO_1'     ,NULL                ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000022','Active'   ,'DN=A User','My_Cred','JOB_VO_1'     ,'JOB_channel_1'     ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000023','Active'   ,'DN=A User','My_Cred','JOB_VO_1'     ,'JOB_channel_1'     ,'source.cern.ch','dest.cern.ch');
    test_create_job('10000000-0000-0000-0000-000000000024','Pending'  ,'DN=A User','My_Cred','JOB_VO_1'     ,'JOB_channel_1'     ,'source.cern.ch','dest.cern.ch', NULL, NULL, 'Y');
    test_create_job('10000000-0000-0000-0000-000000000025','Pending'  ,'DN=A User','My_Cred','JOB_VO_1'     ,'JOB_channel_1'     ,'source.cern.ch','dest.cern.ch', NULL, NULL, 'Y');
    test_create_job('10000000-0000-0000-0000-000000000026','Active'   ,'DN=A User',NULL     ,'CREDJOB_VO_1' ,'CREDJOB_channel_1' ,'source.cern.ch','dest.cern.ch', NULL, NULL, NULL, '1234567', SYSTIMESTAMP - INTERVAL '20' SECOND);
    test_create_job('10000000-0000-0000-0000-000000000027','Failed'   ,'DN=A User',NULL     ,'CREDJOB_VO_1' ,'CREDJOB_channel_1' ,'source.cern.ch','dest.cern.ch', NULL, NULL, NULL, '1234567', SYSTIMESTAMP - INTERVAL '10' SECOND);
    test_create_job('10000000-0000-0000-0000-000000000028','Pending'  ,'DN=A User',NULL     ,'CREDJOB_VO_1' ,'CREDJOB_channel_1' ,'source.cern.ch','dest.cern.ch', NULL, NULL, NULL, '1234567', SYSTIMESTAMP - INTERVAL '30' SECOND);
    test_create_job('10000000-0000-0000-0000-000000000029','Finished' ,'DN=A User',NULL     ,'CREDJOB_VO_1' ,'CREDJOB_channel_1' ,'source.cern.ch','dest.cern.ch', NULL, NULL, NULL, '1234567', SYSTIMESTAMP - INTERVAL '40' SECOND);
    test_create_job('10000000-0000-0000-0000-000000000030','Active'   ,'DN=A User',NULL     ,'JOB_VO_1'     ,'JOB_channel_1' ,'source.cern.ch','dest.cern.ch', NULL, NULL, NULL, '1234567', SYSTIMESTAMP - INTERVAL '30' SECOND,'N');
    test_create_job('10000000-0000-0000-0000-000000000031','Active'   ,'DN=A User',NULL     ,'JOB_VO_1'     ,'JOB_channel_1' ,'source.cern.ch','dest.cern.ch', NULL, NULL, NULL, '1234567', SYSTIMESTAMP - INTERVAL '40' SECOND,'Y');
    test_create_job('20000000-0000-0000-0000-000000000001','Active'   ,'DN=A User','My_Cred','TRANSFER_VO_1','TRANSFER_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('20000000-0000-0000-0000-000000000002','Active'   ,'DN=A User','My_Cred','TRANSFER_VO_2','TRANSFER_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('20000000-0000-0000-0000-000000000003','Active'   ,'DN=A User','My_Cred','TRANSFER_VO_1','TRANSFER_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('20000000-0000-0000-0000-000000000004','Pending'  ,'DN=A User','My_Cred','TRANSFER_VO_1','TRANSFER_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('20000000-0000-0000-0000-000000000005','Active'   ,'DN=A User','My_Cred','TRANSFER_VO_1','TRANSFER_channel_2','source.cern.ch','dest.cern.ch');
    test_create_job('20000000-0000-0000-0000-000000000006','Ready'    ,'DN=A User','My_Cred','TRANSFER_VO_1','TRANSFER_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('20000000-0000-0000-0000-000000000007','Pending'  ,'DN=A User','My_Cred','TRANSFER_VO_1','TRANSFER_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('20000000-0000-0000-0000-000000000008','Active'   ,'DN=A User','My_Cred','TRANSFER_VO_1','TRANSFER_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('30000000-0000-0000-0000-000000000001','Active'   ,'DN=A User','My_Cred','CHANNEL_VO_1' ,'channel_1'         ,'source.cern.ch','dest.cern.ch');
    test_create_job('30000000-0000-0000-0000-000000000002','Active'   ,'DN=A User','My_Cred','CHANNEL_VO_1' ,'channel_1'         ,'source.cern.ch','dest.cern.ch');
    test_create_job('40000000-0000-0000-0000-000000000001','Pending'  ,'DN=A User','My_Cred','STAGEREQ_VO_1','STAGEREQ_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('40000000-0000-0000-0000-000000000002','Pending'  ,'DN=A User','My_Cred','STAGEREQ_VO_2','STAGEREQ_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('40000000-0000-0000-0000-000000000003','Pending'  ,'DN=A User','My_Cred','STAGEREQ_VO_1','STAGEREQ_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('40000000-0000-0000-0000-000000000004','Pending'  ,'DN=A User','My_Cred','STAGEREQ_VO_1','STAGEREQ_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('40000000-0000-0000-0000-000000000005','Pending'  ,'DN=A User','My_Cred','STAGEREQ_VO_2','STAGEREQ_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('40000000-0000-0000-0000-000000000006','Pending'  ,'DN=A User','My_Cred','STAGEREQ_VO_1','STAGEREQ_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('40000000-0000-0000-0000-000000000007','Pending'  ,'DN=A User','My_Cred','STAGEREQ_VO_1','STAGEREQ_channel_1','source.cern.ch','dest.cern.ch');
    test_create_job('50000000-0000-0000-0000-000000000001','Submitted','My DN 1'  ,NULL     ,'CRED_VO_1'    ,NULL                ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_1');
    test_create_job('50000000-0000-0000-0000-000000000002','Pending'  ,'My DN 2'  ,NULL     ,'CRED_VO_2'    ,'CRED_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_2');
    test_create_job('50000000-0000-0000-0000-000000000003','Ready'    ,'My DN 3'  ,NULL     ,'CRED_VO_1'    ,NULL                ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_3');
    test_create_job('50000000-0000-0000-0000-000000000004','Active'   ,'My DN 4'  ,NULL     ,'CRED_VO_2'    ,'CRED_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_4');
    test_create_job('50000000-0000-0000-0000-000000000005','Done'     ,'My DN 5'  ,NULL     ,'CRED_VO_1'    ,NULL                ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_5');
    test_create_job('50000000-0000-0000-0000-000000000006','DoneWithErrors','My DN 6'  ,NULL     ,'CRED_VO_2'    ,'CRED_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_6');
    test_create_job('50000000-0000-0000-0000-000000000007','Hold'     ,'My DN 7'  ,NULL     ,'CRED_VO_1'    ,NULL                ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_7');
    test_create_job('50000000-0000-0000-0000-000000000008','Finishing','My DN 8'  ,NULL     ,'CRED_VO_2'    ,'CRED_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_8');
    test_create_job('50000000-0000-0000-0000-000000000009','Submitted','My DN 9'  ,NULL     ,'CRED_VO_1'    ,NULL                ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_9');
    test_create_job('50000000-0000-0000-0000-000000000010','Pending'  ,'My DN 10' ,NULL     ,'CRED_VO_2'    ,'CRED_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_10');
    test_create_job('50000000-0000-0000-0000-000000000012','Finished' ,'My DN 12' ,NULL     ,'CRED_VO_2'    ,'CRED_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_12');
    test_create_job('50000000-0000-0000-0000-000000000013','Failed'   ,'My DN 13' ,NULL     ,'CRED_VO_2'    ,'CRED_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_13');
    test_create_job('50000000-0000-0000-0000-000000000014','Canceled' ,'My DN 14' ,NULL     ,'CRED_VO_2'    ,'CRED_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_14');
    test_create_job('50000000-0000-0000-0000-000000000016','FinishedDirty' ,'My DN 16' ,NULL     ,'CRED_VO_2'    ,'CRED_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_16');
    test_create_job('50000000-0000-0000-0000-000000000017','Failed'   ,'My DN 17' ,NULL     ,'CRED_VO_2'    ,'CRED_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_17');
    test_create_job('50000000-0000-0000-0000-000000000018','Canceled' ,'My DN 18' ,NULL     ,'CRED_VO_2'    ,'CRED_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_18');
    test_create_job('50000000-0000-0000-0000-100000000008','Finished' ,'My DN 8'  ,NULL     ,'CRED_VO_2'    ,'CRED_channel_1'    ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_8');
    test_create_job('50000000-0000-0000-0000-100000000009','Failed'   ,'My DN 9'  ,NULL     ,'CRED_VO_1'    ,NULL                ,'source.cern.ch','dest.cern.ch',NULL,NULL,NULL,'CRED_id_9');
    -- 3.1.0 specific tests
    test_create_job_finished('60000000-0000-0000-0000-000000000001','Finished'  ,'DN=A User','My_Cred','JOB_VO_1'     ,'JOB_channel_1'     ,'source.cern.ch','dest.cern.ch');
    test_create_job('60000000-0000-0000-0000-000000000002','Active'             ,'DN=A User','My_Cred','FILE_VO_1'    ,'FILE_channel_1'     ,'source.cern.ch','dest.cern.ch');
    --?
    test_create_job('60000000-0000-0000-0000-000000000003','Active'             ,'DN=A User','My_Cred','TRANSFER_VO_1'    ,'TRANSFER_channel_1'     ,'source.cern.ch','dest.cern.ch');
   
    -- bug specific tests
    test_create_job('70000000-0000-0000-0000-000000000001','Active'   ,'DN=A User','My_Cred','bug_vo','bug_channel','source.foo','dest.bar');
   
    -- 3.2.0
    test_create_job('80000000-0000-0000-0000-000000000001','Ready'    ,'DN=A User','My_Cred','JOB_VO_1','JOB_channel_1','source.cern.ch','dest.cern.ch',NULL, NULL, NULL, NULL, NULL, NULL, 'host3.cern.ch', 'host1.cern.ch','someSourceSpaceToken','someSourceTokenDescription');
   
    -- GetShare tests and refactoring  
    test_create_job('90000000-0000-0000-0000-000000000001','Active'   ,'DN=A User','My_Cred','GETSHARE_VO_1','GETSHARE_channel_1','source','dest');
    test_create_job('90000000-0000-0000-0000-000000000002','Ready'    ,'DN=A User','My_Cred','GETSHARE_VO_2','GETSHARE_channel_1','source','dest');

    test_create_job('90000000-0000-0000-0000-000000000003','Ready'    ,'DN=A User','My_Cred','GETSHARE_VO_1','GETSHARE_channel_2','source','dest');
    test_create_job('90000000-0000-0000-0000-000000000004','Ready'    ,'DN=A User','My_Cred','GETSHARE_VO_2','GETSHARE_channel_2','source','dest');
    
    test_create_job('90000000-0000-0000-0000-000000000005','Ready'    ,'DN=A User','My_Cred','GETSHARE_VO_1','GETSHARE_channel_3','source','dest');
    test_create_job('90000000-0000-0000-0000-000000000006','Ready'    ,'DN=A User','My_Cred','GETSHARE_VO_2','GETSHARE_channel_3','source','dest');
    test_create_job('90000000-0000-0000-0000-000000000007','Ready'    ,'DN=A User','My_Cred','GETSHARE_VO_3','GETSHARE_channel_3','source','dest');

    test_create_job('90000000-0000-0000-0000-000000000008','Ready'    ,'DN=A User','My_Cred','GETSHARE_VO_1','GETSHARE_channel_4','source','dest');
    test_create_job('90000000-0000-0000-0000-000000000009','Ready'    ,'DN=A User','My_Cred','GETSHARE_VO_2','GETSHARE_channel_4','source','dest');
    test_create_job('90000000-0000-0000-0000-000000000010','Ready'    ,'DN=A User','My_Cred','GETSHARE_VO_3','GETSHARE_channel_4','source','dest');
    test_create_job('90000000-0000-0000-0000-000000000011','Ready'    ,'DN=A User','My_Cred','GETSHARE_VO_4','GETSHARE_channel_4','source','dest');
    test_create_job('90000000-0000-0000-0000-000000000012','Ready'    ,'DN=A User','My_Cred','GETSHARE_VO_4','GETSHARE_channel_4','source','dest');
    
    -- 3.3.0
    create_job_330( '00000010-0000-0000-0000-000000000001','Ready'    ,'DN=A User','My_Cred','JOB_VO_1','JOB_channel_1',NULL,NULL,NULL);      
    create_job_330( '00000010-0000-0000-0000-000000000002','Ready'    ,'DN=A User','My_Cred','JOB_VO_1','JOB_channel_1',100,'Y','Y');      
    create_job_330( '00000010-0000-0000-0000-000000000003','Ready'    ,'DN=A User','My_Cred','JOB_VO_1','JOB_channel_1',100,'N','N');      
    
    -- 3.4.1
    create_job_341( '00000011-0000-0000-0000-000000000001','Ready'    ,'DN=A User','My_Cred','JOB_VO_1','JOB_channel_1',NULL,NULL,NULL,NULL);      
    create_job_341( '00000011-0000-0000-0000-000000000002','Ready'    ,'DN=A User','My_Cred','JOB_VO_1','JOB_channel_1',100,'Y','Y','N');      
    create_job_341( '00000011-0000-0000-0000-000000000003','Ready'    ,'DN=A User','My_Cred','JOB_VO_1','JOB_channel_1',100,'Y','Y','Y');      
    END;
/
